<?php

/**
 *
 * @link              https://wphotline.com
 * @since             1.0
 * @package           gdprcompatible
 *
 * @codeable72522
 * Plugin Name:       GDPR ✔Check
 * Description:       Is your site ready for the GDPR?
 * Version:           1.0.1
 * Author:            Stefan Boettcher
 * Author URI:        https://wphotline.com
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       gdprcompatible
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}


//help debugging
if (!function_exists('var_dumpp')) {
function var_dumpp( $input ) {
  echo '<pre>';
  var_dump( $input );
  echo '</pre>';
}
}

add_action( 'admin_menu', 'gdprcompatible_register_settings_page' );
function gdprcompatible_register_settings_page(){
    add_menu_page( 'GDPR ready?', 'GDPR ✔', 'manage_options', 'gdprcompatible-settings', 'gdprcompatible_show_settings_page', 'dashicons-tablet' , 6 );
}

function gdprcompatible_show_settings_page(){
		include_once('settings.php');
}

add_action( 'admin_post_gdprcompatible_save_status', 'gdprcompatible_save_status' );
function gdprcompatible_save_status() {
	//var_dumpp( $_POST );
	$_POST["data"]["done_avv"] = $_POST["done_avv_data"];
	$_POST["data"]["done_datenschutz"] = $_POST["done_datenschutz_data"];
	$_POST["data"]["last_updated"] = time();
	$_POST["data"]["last_user"] = get_current_user_id();

	// Good idea to make sure things are set before using them
	$data = isset( $_POST['data'] ) ? (array) $_POST['data'] : array();
	array_walk_recursive($data,'gdprcompatible_esc_array');

	//var_dumpp( $data );

	update_option( 'gdprcompatible_status', wp_json_encode( $data ) );
	wp_redirect( esc_url( admin_url('admin.php?page=gdprcompatible-settings') ) );
	exit();
}


function gdprcompatible_esc_array( &$item, $key ) {
    $item = esc_attr($item);
		return $item;
}



function gdprcompatible_is_activated( $plugin ){

	$return = false;

	switch( $plugin ) {
		case "WooCommerce":
			if ( class_exists( 'WooCommerce' ) ) {
			  $return = true;
			}
		break;
		case "CF7":
		if ( class_exists( 'WPCF7_ContactForm' ) ) {
			$return = true;
		}
		break;

	}
	return $return;

}

//redirect on activate
register_activation_hook(__FILE__, 'gdprcompatible_activate');
add_action('admin_init', 'gdprcompatible_redirect');

function gdprcompatible_activate() {
	add_option('gdprcompatible_do_activation_redirect', true);
}

function gdprcompatible_redirect() {
if (get_option('gdprcompatible_do_activation_redirect', false)) {
    delete_option('gdprcompatible_do_activation_redirect');
		//not on bulk activation
    if(!isset($_GET['activate-multi']))
    {
        wp_redirect( esc_url( admin_url('admin.php?page=gdprcompatible-settings')) );
				exit;
    }
 }
}

//add settings link
$plugin = plugin_basename( __FILE__ );
add_filter( "plugin_action_links_$plugin", 'gdprcompatible_add_settings_link' );

function gdprcompatible_add_settings_link( $links ) {
    $settings_link = '<a href="' .esc_url( admin_url('admin.php?page=gdprcompatible-settings') ). '">' . __( 'Settings' ) . '</a>';
    array_push( $links, $settings_link );
  	return $links;
}
